@@ -42,7 +42,9 @@ static gboolean lxterminal_socket_read_channel(GIOChannel * gio, GIOCondition co
     GError * err = NULL;
     GIOStatus ret = g_io_channel_read_line(gio, &msg, &len, &term, &err);
     if (ret == G_IO_STATUS_ERROR)
+    {
         g_warning("Error reading socket: %s\n", err->message);
+    }
 
     /* Process message. */
     if (len > 0)
@@ -57,14 +59,16 @@ static gboolean lxterminal_socket_read_channel(GIOChannel * gio, GIOCondition co
         g_shell_parse_argv(msg, &argc, &argv, NULL);
         CommandArguments arguments;
         lxterminal_process_arguments(argc, argv, &arguments);
-        lxterminal_initialize(lxtermwin, &arguments, lxtermwin->setting);
+        lxterminal_initialize(lxtermwin, &arguments);
         g_strfreev(argv);
     }
     g_free(msg);
 
     /* If there was a disconnect, discontinue read.  Otherwise, continue. */
     if (condition & G_IO_HUP)
+    {
         return FALSE;
+    }
     return TRUE;
 }
 
@@ -193,7 +197,7 @@ gboolean lxterminal_socket_initialize(LXTermWindow * lxtermwin, CommandArguments
         g_io_channel_set_encoding(gio, NULL, NULL);
 
         /* Reissue arguments to the socket.  Start with the name of the executable. */
-	g_io_channel_write_chars(gio, arguments->executable, -1, NULL, NULL);
+        g_io_channel_write_chars(gio, arguments->executable, -1, NULL, NULL);
 
         /* --command or -e. */
         if (arguments->command != NULL)
@@ -213,18 +217,18 @@ gboolean lxterminal_socket_initialize(LXTermWindow * lxtermwin, CommandArguments
             g_free(geometry);
         }
 
-        /* -t, -T, or --title. */
-        if (arguments->title != NULL)
+        /* -t, -T, --title or --tabs. */
+        if (arguments->tabs != NULL)
         {
-            gchar * title = g_shell_quote(arguments->title);
-            gchar * title_argument = g_strdup_printf(" --title=%s", title);
-            g_io_channel_write_chars(gio, title_argument, -1, NULL, NULL);
-            g_free(title);
-            g_free(title_argument);
+            gchar * tabs = g_shell_quote(arguments->tabs);
+            gchar * tabs_argument = g_strdup_printf(" --tabs=%s", tabs);
+            g_io_channel_write_chars(gio, tabs_argument, -1, NULL, NULL);
+            g_free(tabs);
+            g_free(tabs_argument);
         }
 
         /* Always issue a --working-directory, either from the user's specification or the current directory. */
-        gchar * working_directory = ((arguments->working_directory != NULL) ? g_shell_quote(arguments->working_directory) : g_get_current_dir());
+        gchar * working_directory = g_shell_quote((arguments->working_directory != NULL) ? arguments->working_directory : g_get_current_dir());
         gchar * working_directory_argument = g_strdup_printf(" --working-directory=%s", working_directory);
         g_io_channel_write_chars(gio, working_directory_argument, -1, NULL, NULL);
         g_free(working_directory);
